==> tree-component-3.3.3.tgz: package/angular.js <==
"use strict";
import { Component, Input, Output, EventEmitter, NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import * as common from "./common";
export * from "./common";
import { angularNodeTemplateHtml, angularTreeTemplateHtml } from "./angular-variables";
/**
 * @public
 */
var NodeComponent = (function () {
    function NodeComponent() {
        this.toggle = new EventEmitter();
        this.change = new EventEmitter();
        this.hovered = false;
        this.doubleClick = new common.DoubleClick();
    }
    Object.defineProperty(NodeComponent.prototype, "nodeClassName", {
        get: function () {
            return common.getNodeClassName(this.data, this.last);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "anchorClassName", {
        get: function () {
            return common.getAnchorClassName(this.data, this.hovered, this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "checkboxClassName", {
        get: function () {
            return common.getCheckboxClassName(this.data, this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "iconClassName", {
        get: function () {
            return common.getIconClassName(this.data.icon);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "oclClassName", {
        get: function () {
            return common.getOclClassName(this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "pathString", {
        get: function () {
            return this.path.toString();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "hasMarker", {
        get: function () {
            return this.draggable && this.data.state.dropPosition !== 0 /* empty */;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "markerClassName", {
        get: function () {
            return common.getMarkerClassName(this.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "eventData", {
        get: function () {
            return {
                data: this.data,
                path: this.path,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "id", {
        get: function () {
            return common.getId(this.path, this.preid);
        },
        enumerable: true,
        configurable: true
    });
    NodeComponent.prototype.geChildPath = function (index) {
        return this.path.concat(index);
    };
    NodeComponent.prototype.hover = function (hovered) {
        this.hovered = hovered;
    };
    NodeComponent.prototype.ontoggle = function (eventData) {
        if (eventData) {
            this.toggle.emit(eventData);
        }
        else {
            if (this.data.state.openable || this.data.children.length > 0) {
                this.toggle.emit(this.eventData);
            }
        }
    };
    NodeComponent.prototype.onchange = function (eventData) {
        var _this = this;
        if (eventData) {
            this.change.emit(eventData);
        }
        else {
            if (this.data.state.disabled) {
                return;
            }
            this.doubleClick.onclick(function () {
                _this.change.emit(_this.eventData);
            });
        }
    };
    NodeComponent.decorators = [
        { type: Component, args: [{
                    selector: "node",
                    template: angularNodeTemplateHtml,
                },] },
    ];
    /** @nocollapse */
    NodeComponent.ctorParameters = function () { return []; };
    NodeComponent.propDecorators = {
        'data': [{ type: Input },],
        'last': [{ type: Input },],
        'checkbox': [{ type: Input },],
        'path': [{ type: Input },],
        'draggable': [{ type: Input },],
        'preid': [{ type: Input },],
        'toggle': [{ type: Output },],
        'change': [{ type: Output },],
    };
    return NodeComponent;
}());
export { NodeComponent };
/**
 * @public
 */
var TreeComponent = (function () {
    function TreeComponent() {
        this.toggle = new EventEmitter();
        this.change = new EventEmitter();
        this.drop = new EventEmitter();
        this.dragTarget = null;
        this.dropTarget = null;
    }
    Object.defineProperty(TreeComponent.prototype, "rootClassName", {
        get: function () {
            return common.getRootClassName(this.checkbox, this.size, this.theme);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeComponent.prototype, "containerClassName", {
        get: function () {
            return common.getContainerClassName(this.nodots);
        },
        enumerable: true,
        configurable: true
    });
    TreeComponent.prototype.ontoggle = function (eventData) {
        this.toggle.emit(eventData);
    };
    TreeComponent.prototype.onchange = function (eventData) {
        this.change.emit(eventData);
    };
    TreeComponent.prototype.ondragstart = function (event) {
        if (!this.draggable) {
            return;
        }
        this.dragTarget = event.target;
        this.dropTarget = event.target;
    };
    TreeComponent.prototype.ondragend = function (event) {
        if (!this.draggable) {
            return;
        }
        this.dragTarget = null;
        for (var _i = 0, _a = this.data; _i < _a.length; _i++) {
            var tree = _a[_i];
            common.clearMarkerOfTree(tree);
        }
    };
    TreeComponent.prototype.ondragover = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.data, this.dropAllowed);
        event.preventDefault();
    };
    TreeComponent.prototype.ondragenter = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        this.dropTarget = event.target;
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.data, this.dropAllowed);
    };
    TreeComponent.prototype.ondragleave = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        if (event.target === this.dropTarget) {
            this.dropTarget = null;
        }
        common.ondragleave(event.target, this.data);
    };
    TreeComponent.prototype.ondrop = function (event) {
        var _this = this;
        event.stopPropagation();
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrop(event.target, this.dragTarget, this.data, function (dropData) {
            _this.drop.emit(dropData);
        });
    };
    TreeComponent.prototype.canDrop = function (event) {
        return this.draggable && event.target && event.target.dataset && event.target.dataset.path;
    };
    TreeComponent.decorators = [
        { type: Component, args: [{
                    selector: "tree",
                    template: angularTreeTemplateHtml,
                },] },
    ];
    /** @nocollapse */
    TreeComponent.ctorParameters = function () { return []; };
    TreeComponent.propDecorators = {
        'data': [{ type: Input },],
        'checkbox': [{ type: Input },],
        'draggable': [{ type: Input },],
        'nodots': [{ type: Input },],
        'size': [{ type: Input },],
        'theme': [{ type: Input },],
        'dropAllowed': [{ type: Input },],
        'preid': [{ type: Input },],
        'toggle': [{ type: Output },],
        'change': [{ type: Output },],
        'drop': [{ type: Output },],
    };
    return TreeComponent;
}());
export { TreeComponent };
/**
 * @public
 */
var TreeModule = (function () {
    function TreeModule() {
    }
    TreeModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        TreeComponent,
                        NodeComponent,
                    ],
                    imports: [
                        CommonModule,
                    ],
                    exports: [
                        TreeComponent,
                        NodeComponent,
                    ],
                },] },
    ];
    /** @nocollapse */
    TreeModule.ctorParameters = function () { return []; };
    return TreeModule;
}());
export { TreeModule };

==> tree-component-4.0.1.tgz: package/angular.js <==
"use strict";
import * as tslib_1 from "tslib";
import { Component, Input, Output, EventEmitter, NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import * as common from "./common";
export * from "./common";
import { angularNodeTemplateHtml, angularTreeTemplateHtml } from "./angular-variables";
/**
 * @public
 */
var NodeComponent = (function () {
    function NodeComponent() {
        this.toggle = new EventEmitter();
        this.change = new EventEmitter();
        this.hovered = false;
        this.doubleClick = new common.DoubleClick();
    }
    Object.defineProperty(NodeComponent.prototype, "nodeClassName", {
        get: function () {
            return common.getNodeClassName(this.data, this.last);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "anchorClassName", {
        get: function () {
            return common.getAnchorClassName(this.data, this.hovered, this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "checkboxClassName", {
        get: function () {
            return common.getCheckboxClassName(this.data, this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "iconClassName", {
        get: function () {
            return common.getIconClassName(this.data.icon);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "oclClassName", {
        get: function () {
            return common.getOclClassName(this.path);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "pathString", {
        get: function () {
            return this.path.toString();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "hasMarker", {
        get: function () {
            return this.draggable && this.data.state.dropPosition !== 0 /* empty */;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "markerClassName", {
        get: function () {
            return common.getMarkerClassName(this.data);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "eventData", {
        get: function () {
            return {
                data: this.data,
                path: this.path,
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NodeComponent.prototype, "id", {
        get: function () {
            return common.getId(this.path, this.preid);
        },
        enumerable: true,
        configurable: true
    });
    NodeComponent.prototype.geChildPath = function (index) {
        return this.path.concat(index);
    };
    NodeComponent.prototype.hover = function (hovered) {
        this.hovered = hovered;
    };
    NodeComponent.prototype.ontoggle = function (eventData) {
        if (eventData) {
            this.toggle.emit(eventData);
        }
        else {
            if (this.data.state.openable || this.data.children.length > 0) {
                this.toggle.emit(this.eventData);
            }
        }
    };
    NodeComponent.prototype.onchange = function (eventData) {
        var _this = this;
        if (eventData) {
            this.change.emit(eventData);
        }
        else {
            if (this.data.state.disabled) {
                return;
            }
            this.doubleClick.onclick(function () {
                _this.change.emit(_this.eventData);
            });
        }
    };
    NodeComponent.prototype.trackBy = function (request, index) {
        return index;
    };
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object)
    ], NodeComponent.prototype, "data", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], NodeComponent.prototype, "last", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], NodeComponent.prototype, "checkbox", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Array)
    ], NodeComponent.prototype, "path", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], NodeComponent.prototype, "draggable", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], NodeComponent.prototype, "preid", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], NodeComponent.prototype, "toggle", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], NodeComponent.prototype, "change", void 0);
    NodeComponent = tslib_1.__decorate([
        Component({
            selector: "node",
            template: angularNodeTemplateHtml,
        })
    ], NodeComponent);
    return NodeComponent;
}());
export { NodeComponent };
/**
 * @public
 */
var TreeComponent = (function () {
    function TreeComponent() {
        this.toggle = new EventEmitter();
        this.change = new EventEmitter();
        this.drop = new EventEmitter();
        this.dragTarget = null;
        this.dropTarget = null;
    }
    Object.defineProperty(TreeComponent.prototype, "rootClassName", {
        get: function () {
            return common.getRootClassName(this.checkbox, this.size, this.theme);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TreeComponent.prototype, "containerClassName", {
        get: function () {
            return common.getContainerClassName(this.nodots);
        },
        enumerable: true,
        configurable: true
    });
    TreeComponent.prototype.ontoggle = function (eventData) {
        this.toggle.emit(eventData);
    };
    TreeComponent.prototype.onchange = function (eventData) {
        this.change.emit(eventData);
    };
    TreeComponent.prototype.ondragstart = function (event) {
        if (!this.draggable) {
            return;
        }
        this.dragTarget = event.target;
        this.dropTarget = event.target;
    };
    TreeComponent.prototype.ondragend = function (event) {
        if (!this.draggable) {
            return;
        }
        this.dragTarget = null;
        for (var _i = 0, _a = this.data; _i < _a.length; _i++) {
            var tree = _a[_i];
            common.clearMarkerOfTree(tree);
        }
    };
    TreeComponent.prototype.ondragover = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.data, this.dropAllowed);
        event.preventDefault();
    };
    TreeComponent.prototype.ondragenter = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        this.dropTarget = event.target;
        common.ondrag(event.pageY, this.dragTarget, this.dropTarget, this.data, this.dropAllowed);
    };
    TreeComponent.prototype.ondragleave = function (event) {
        if (!this.canDrop(event)) {
            return;
        }
        if (event.target === this.dropTarget) {
            this.dropTarget = null;
        }
        common.ondragleave(event.target, this.data);
    };
    TreeComponent.prototype.ondrop = function (event) {
        var _this = this;
        event.stopPropagation();
        if (!this.canDrop(event)) {
            return;
        }
        common.ondrop(event.target, this.dragTarget, this.data, function (dropData) {
            _this.drop.emit(dropData);
        });
    };
    TreeComponent.prototype.trackBy = function (request, index) {
        return index;
    };
    TreeComponent.prototype.canDrop = function (event) {
        return this.draggable && event.target && event.target.dataset && event.target.dataset.path;
    };
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Array)
    ], TreeComponent.prototype, "data", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], TreeComponent.prototype, "checkbox", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], TreeComponent.prototype, "draggable", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean)
    ], TreeComponent.prototype, "nodots", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], TreeComponent.prototype, "size", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], TreeComponent.prototype, "theme", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Function)
    ], TreeComponent.prototype, "dropAllowed", void 0);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String)
    ], TreeComponent.prototype, "preid", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], TreeComponent.prototype, "toggle", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], TreeComponent.prototype, "change", void 0);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", Object)
    ], TreeComponent.prototype, "drop", void 0);
    TreeComponent = tslib_1.__decorate([
        Component({
            selector: "tree",
            template: angularTreeTemplateHtml,
        })
    ], TreeComponent);
    return TreeComponent;
}());
export { TreeComponent };
/**
 * @public
 */
var TreeModule = (function () {
    function TreeModule() {
    }
    TreeModule = tslib_1.__decorate([
        NgModule({
            declarations: [
                TreeComponent,
                NodeComponent,
            ],
            imports: [
                CommonModule,
            ],
            exports: [
                TreeComponent,
                NodeComponent,
            ],
        })
    ], TreeModule);
    return TreeModule;
}());
export { TreeModule };
